@@ -1,6 +1,6 @@
 package EBook::Ishmael::EBook::HTML;
 use 5.016;
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 use strict;
 use warnings;
 
@@ -93,11 +93,13 @@ sub new {
 	my $class = shift;
 	my $file  = shift;
 	my $enc   = shift;
+	my $net   = shift // 1;
 
 	my $self = {
 		Source   => undef,
 		Metadata => EBook::Ishmael::EBook::Metadata->new,
 		Encode   => $enc,
+		Network  => $net,
 		_dom     => undef,
 	};
 
@@ -107,6 +109,7 @@ sub new {
 
 	$self->{_dom} = XML::LibXML->load_html(
 		location => $file,
+		no_network => !$self->{Network},
 		recover => 2,
 		encoding => $self->{Encode},
 	);
